yt.analysis_modules.cosmological_observation.light_cone.light_cone.LightCone.plan_cosmology_splice — The yt Project 3.2-dev documentation

# yt.analysis_modules.cosmological_observation.light_cone.light_cone.LightCone.plan_cosmology_splice

`LightCone.` `plan_cosmology_splice`(near_redshift, far_redshift, decimals=3, filename=None, start_index=0)

  Create imaginary list of redshift outputs to maximally span a redshift interval.

  If you want to run a cosmological simulation that will have just enough data outputs to create a cosmology splice, this method will calculate a list of redshifts outputs that will minimally connect a redshift interval.

  Parameters: | near_redshift : float The nearest (lowest) redshift in the cosmology splice list. far_redshift : float The furthest (highest) redshift in the cosmology splice list. decimals : int The decimal place to which the output redshift will be rounded. If the decimal place in question is nonzero, the redshift will be rounded up to ensure continuity of the splice. Default: 3. filename : string If provided, a file will be written with the redshift outputs in the form in which they should be given in the enzo dataset. Default: None. start_index : int The index of the first redshift output. Default: 0.

  Examples

      >>> from yt.analysis_modules.api import CosmologySplice
      >>> my_splice = CosmologySplice('enzo_tiny_cosmology/32Mpc_32.enzo', 'Enzo')
      >>> my_splice.plan_cosmology_splice(0.0, 0.1, filename='redshifts.out')